@@ -8,9 +8,9 @@ loop = asyncio.get_event_loop()
 def test_read_jsonb(model):
     class Card(Model):
         pass
-    card = loop.run_until_complete(Card.find(5))
+    card = loop.run_until_complete(Card.find(4))
     assert card.data == {
-        "finished": False,
+        "finished": True,
         "name": "Hang paintings",
         "tags": [
             "Improvements",
@@ -18,6 +18,7 @@ def test_read_jsonb(model):
         ]
     }
 
+
 def test_write_jsonb(model):
     class Card(Model):
         pass
@@ -32,4 +33,4 @@ def test_write_jsonb(model):
     assert card.id > 0
     card = loop.run_until_complete(Card.find(card.id))
     assert card.data == 'plain string as json'
-    loop.run_until_complete(Card.where('id', card.id).delete())
\ No newline at end of file
+    loop.run_until_complete(Card.where('id', card.id).delete())
